package com.utopiaindustries.selftrucking.Activities.dashboardScreens;

import android.content.Context;
import android.content.Intent;
import android.graphics.Color;
import android.graphics.drawable.ColorDrawable;
import android.os.Bundle;
import android.text.Html;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.AutoCompleteTextView;
import android.widget.ImageView;
import android.widget.TextView;
import android.widget.Toast;

import androidx.activity.EdgeToEdge;
import androidx.appcompat.app.AlertDialog;
import androidx.appcompat.app.AppCompatActivity;
import androidx.core.graphics.Insets;
import androidx.core.view.ViewCompat;
import androidx.core.view.WindowInsetsCompat;
import androidx.lifecycle.ViewModelProvider;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.utopiaindustries.selftrucking.Activities.dashboardScreens.adapters.ContainerAdapter;
import com.utopiaindustries.selftrucking.Activities.dashboardScreens.apiservice.ApiService;
import com.utopiaindustries.selftrucking.Activities.dashboardScreens.apiservice.ApiServiceFactory;
import com.utopiaindustries.selftrucking.Activities.dashboardScreens.apiservice.MotiveApiService;
import com.utopiaindustries.selftrucking.Activities.dashboardScreens.interfaces.SelectListener;
import com.utopiaindustries.selftrucking.Activities.dashboardScreens.viewModels.HomeViewModel;
import com.utopiaindustries.selftrucking.Activities.loginScreens.LoginActivity;
import com.utopiaindustries.selftrucking.helper.Helper;
import com.utopiaindustries.selftrucking.helper.Preference;
import com.utopiaindustries.selftrucking.models.Container;
import com.utopiaindustries.selftrucking.R;
import com.utopiaindustries.selftrucking.models.ContainerWorkflow;
import com.utopiaindustries.selftrucking.models.DriverResponse;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import retrofit2.Call;
import retrofit2.Callback;
import retrofit2.Response;

public class HomeActivity extends AppCompatActivity implements SelectListener {

    String[] item = {"All", "Assigned", "Picked", "Dropped", "Completed"};
    AutoCompleteTextView autoCompleteTextView;
    ArrayAdapter<String> adapterItems;
    HomeViewModel homeViewModel;
    RecyclerView containerRecyclerView;
    ContainerAdapter adapter;
    List<ContainerWorkflow> containerList = new ArrayList<>();
    List<ContainerWorkflow> tempList = new ArrayList<>();
    ApiService apiService;
    MotiveApiService motiveApiService;
    DriverResponse driverResponse;
    TextView txtDriverName, txtNoData;
    ImageView imgLogout;
    int currentPositionStatus = 0;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        EdgeToEdge.enable(this);
        setContentView(R.layout.activity_home);
        ViewCompat.setOnApplyWindowInsetsListener(findViewById(R.id.main), (v, insets) -> {
            Insets systemBars = insets.getInsets(WindowInsetsCompat.Type.systemBars());
            v.setPadding(systemBars.left, systemBars.top, systemBars.right, systemBars.bottom);
            return insets;
        });

        if (!Helper.isNetworkConnected(this)) {
            Toast.makeText(this, "No Internet Connection", Toast.LENGTH_LONG).show();
        }

        initializeLayout();

        autoCompleteTextView.setOnItemClickListener(new AdapterView.OnItemClickListener() {
            @Override
            public void onItemClick(AdapterView<?> adapterView, View view, int position, long l) {
                String item = adapterView.getItemAtPosition(position).toString();
                Log.e("Item-----------: ", "" + item);
                filterList(item);

            }
        });

        imgLogout.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                alertLogOut(HomeActivity.this);
            }
        });
    }

    public void initializeLayout() {
        homeViewModel = new ViewModelProvider(this).get(HomeViewModel.class);
        containerRecyclerView = findViewById(R.id.container_list);
        containerRecyclerView.setLayoutManager(new LinearLayoutManager(this));
        apiService = ApiServiceFactory.getApiService();
        motiveApiService = ApiServiceFactory.getMotiveApiService();
        txtDriverName = findViewById(R.id.txt_driver_name);
        txtNoData = findViewById(R.id.txt_no_data);
        imgLogout = findViewById(R.id.img_logout);

        autoCompleteTextView = findViewById(R.id.auto_complete_textview);
        adapterItems = new ArrayAdapter<String>(this, R.layout.list_items, item);
        autoCompleteTextView.setAdapter(adapterItems);
        if (item.length > 0) {
            boolean keyExists = Preference.containsKey(Helper.project_file, "CurrentPosition", this);
            if (keyExists) {
                //Log.e("Key-Exist: ", "True");
                currentPositionStatus = Preference.getMyIntPref(Helper.project_file, "CurrentPosition", this);
                autoCompleteTextView.setText(item[currentPositionStatus], false);
            } else {
                //Log.e("Key-Exist: ", "False");
                autoCompleteTextView.setText(item[0], false);
            }
        }
    }

    private void filterList(String status) {
        containerList.clear();
        for (ContainerWorkflow cx : tempList) {
            Log.e("tempList-status: ", "" + cx.getCurrentStatus());
        }


        if (status.equals("All")) {
            containerList.addAll(tempList);
        } /*else if (status.equalsIgnoreCase("Assigned")) {
            for (ContainerWorkflow item : tempList) {
                if (item.getCurrentStatus() != null
                        && !item.getCurrentStatus().equalsIgnoreCase("Picked")
                        && !item.getCurrentStatus().equalsIgnoreCase("Dropped")
                        && !item.getCurrentStatus().equalsIgnoreCase("Completed")) {
                    containerList.add(item);
                }
            }
        }*/ else {
            for (ContainerWorkflow item : tempList) {
                if (item.getCurrentStatus() != null && item.getCurrentStatus().equalsIgnoreCase(status)) {
                    containerList.add(item);
                }
            }
        }

        if (!containerList.isEmpty()) {
            txtNoData.setVisibility(View.GONE);
        } else {
            txtNoData.setVisibility(View.VISIBLE);
        }

        adapter.notifyDataSetChanged();
    }

    @Override
    public void onItemClicked(ContainerWorkflow container, int pos) {
        if (container.getCurrentStatus() != null && container.getCurrentStatus().equalsIgnoreCase("COMPLETED")) {
            Toast.makeText(this, "Already Completed", Toast.LENGTH_SHORT).show();
        } else {
            //Toast.makeText(this, String.valueOf(container.getContainerNo()), Toast.LENGTH_SHORT).show();

            Intent intent = new Intent(HomeActivity.this, ContainerDetailActivity.class);
            intent.putExtra("TruckerId", driverResponse.getTruckerId().toString());
            intent.putExtra("TruckerName", driverResponse.getTruckerName());
            intent.putExtra("position", pos);
            intent.putExtra("SingleContainerInfo", (Serializable) container);
            startActivity(intent);
            overridePendingTransition(R.anim.slide_in_right, R.anim.slide_out_left);
        }
    }

    private void fetchAssignedContainers() {
        apiService.fetchAllReports("").enqueue(new Callback<List<Container>>() {
            @Override
            public void onResponse(Call<List<Container>> call, Response<List<Container>> response) {
                if (response.isSuccessful() && response.body() != null) {

                } else {

                }
            }

            @Override
            public void onFailure(Call<List<Container>> call, Throwable t) {
                System.out.println(t.getMessage());
            }
        });
    }

    private void fetchTruckLocation() {
        motiveApiService.getDriverLocation("").enqueue(new Callback<List<Container>>() {
            @Override
            public void onResponse(Call<List<Container>> call, Response<List<Container>> response) {

            }

            @Override
            public void onFailure(Call<List<Container>> call, Throwable t) {

            }
        });
    }

    public void alertLogOut(Context con) {
        ViewGroup viewGroup = findViewById(android.R.id.content);

        TextView dialogOkBtn, dialogCancelBtn;

        AlertDialog.Builder builder = new AlertDialog.Builder(con);
        View view1 = LayoutInflater.from(con).inflate(R.layout.custom_layout_for_logout, viewGroup, false);
        builder.setCancelable(false);
        builder.setView(view1);

        dialogOkBtn = view1.findViewById(R.id.dialogOkBtn);
        dialogCancelBtn = view1.findViewById(R.id.dialogCancelBtn);

        AlertDialog alertDialog = builder.create();
        alertDialog.getWindow().setBackgroundDrawable(new ColorDrawable(Color.TRANSPARENT));

        dialogOkBtn.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {

                alertDialog.dismiss();
                //Toast.makeText(con, "Ok", Toast.LENGTH_SHORT).show();

                Preference.setMyBooleanPref(Helper.project_file, "isLoggedIn", getApplicationContext(), false);
                Preference.setMyIntPref(Helper.project_file, "CurrentPosition",getApplicationContext(),0);

                finish();
                Intent i = new Intent(HomeActivity.this, LoginActivity.class);
                i.addFlags(Intent.FLAG_ACTIVITY_CLEAR_TOP | Intent.FLAG_ACTIVITY_NEW_TASK);
                startActivity(i);
                overridePendingTransition(R.anim.slide_in_right, R.anim.slide_out_left);

            }
        });

        dialogCancelBtn.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {

                alertDialog.dismiss();
                //Toast.makeText(con, "Cancel", Toast.LENGTH_SHORT).show();

            }
        });

        alertDialog.show();
    }

    @Override
    protected void onResume() {
        super.onResume();

        containerList.clear();
        tempList.clear();
        driverResponse = Helper.getPreferenceObjectJson(this, "DriverResponse");
        assert driverResponse != null;
        containerList.addAll(driverResponse.getContainerWorkflowData());
        tempList.addAll(driverResponse.getContainerWorkflowData());

        //dummyData();
        txtDriverName.setText(Html.fromHtml("Welcome: " + "<b>" + driverResponse.getTruckerName() + "</b>", Html.FROM_HTML_MODE_LEGACY));

        adapter = new ContainerAdapter(containerList, this, HomeActivity.this);
        containerRecyclerView.setAdapter(adapter);

        if (!containerList.isEmpty()) {
            txtNoData.setVisibility(View.GONE);
        } else {
            txtNoData.setVisibility(View.VISIBLE);
        }

        if (item.length > 0) {
            boolean keyExists = Preference.containsKey(Helper.project_file, "CurrentPosition", this);
            if (keyExists) {
                //Log.e("Key-Exist: ", "True");
                currentPositionStatus = Preference.getMyIntPref(Helper.project_file, "CurrentPosition", this);
                autoCompleteTextView.setText(item[currentPositionStatus], false);
                filterList(item[currentPositionStatus]);
            } else {
                //Log.e("Key-Exist: ", "False");
                autoCompleteTextView.setText(item[0], false);
                filterList(item[currentPositionStatus]);
            }
        }
    }
}