package com.utopiaindustries.selftrucking.Activities.dashboardScreens.adapters;

import android.content.Context;
import android.content.Intent;
import android.text.Html;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.core.content.ContextCompat;
import androidx.recyclerview.widget.RecyclerView;

import com.utopiaindustries.selftrucking.Activities.dashboardScreens.ContainerDetailActivity;
import com.utopiaindustries.selftrucking.Activities.dashboardScreens.HomeActivity;
import com.utopiaindustries.selftrucking.Activities.dashboardScreens.interfaces.SelectListener;
import com.utopiaindustries.selftrucking.models.Container;
import com.utopiaindustries.selftrucking.R;
import com.utopiaindustries.selftrucking.models.ContainerWorkflow;

import java.util.List;

public class ContainerAdapter extends RecyclerView.Adapter<ContainerAdapter.ContainerViewHolder> {

    private List<ContainerWorkflow> containerList;
    private SelectListener listener;
    private Context context;

    public ContainerAdapter(List<ContainerWorkflow> containerList, SelectListener listener, Context context) {
        this.containerList = containerList;
        this.listener = listener;
        this.context = context;
    }

    @NonNull
    @Override
    public ContainerViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
        View view = LayoutInflater.from(parent.getContext()).inflate(R.layout.item_container, parent, false);
        return new ContainerViewHolder(view);
    }

    @Override
    public void onBindViewHolder(@NonNull ContainerViewHolder holder, int position) {
        ContainerWorkflow container = containerList.get(position);

        //holder.container_no.setText(Html.fromHtml("<b>Container No:</b> " + container.getContainerNo(), Html.FROM_HTML_MODE_LEGACY));
        holder.container_no.setText(container.getContainerNo());
        holder.container_origin.setText(container.getOrigin());
        holder.container_destination.setText(container.getDestination());
        if (container.getCurrentStatus() != null && !container.getCurrentStatus().equalsIgnoreCase("")) {
            holder.container_status.setText(container.getCurrentStatus());
        } else {
            holder.container_status.setText("Assigned");
        }

        if (container.getCurrentStatus() != null && !container.getCurrentStatus().equalsIgnoreCase("")) {
            switch (container.getCurrentStatus()) {

                case "PICKED":
                    holder.container_status.setBackgroundColor(ContextCompat.getColor(context, R.color.picked_color));
                    break;

                case "DROPPED":
                    holder.container_status.setBackgroundColor(ContextCompat.getColor(context, R.color.dropped_color));
                    break;

                case "COMPLETED":
                    holder.container_status.setBackgroundColor(ContextCompat.getColor(context, R.color.completed_color));
                    break;

                default:
                    holder.container_status.setBackgroundColor(ContextCompat.getColor(context, R.color.theme_color));

            }
        } else {
            holder.container_status.setBackgroundColor(ContextCompat.getColor(context, R.color.theme_color));
        }

        holder.itemView.setOnClickListener(v -> listener.onItemClicked(container, position));
    }

    @Override
    public int getItemCount() {
        return containerList.size();
    }

    public static class ContainerViewHolder extends RecyclerView.ViewHolder {
        TextView container_no, container_origin, container_destination, container_status;

        public ContainerViewHolder(@NonNull View itemView) {
            super(itemView);
            container_no = itemView.findViewById(R.id.container_no);
            container_origin = itemView.findViewById(R.id.container_origin);
            container_destination = itemView.findViewById(R.id.container_destination);
            container_status = itemView.findViewById(R.id.container_status);
        }
    }
}
