package com.utopiaindustries.selftrucking.Activities.dashboardScreens.viewModels;

import android.util.Log;

import androidx.annotation.NonNull;
import androidx.lifecycle.LiveData;
import androidx.lifecycle.MutableLiveData;
import androidx.lifecycle.ViewModel;

import com.utopiaindustries.selftrucking.Activities.dashboardScreens.apiservice.ApiService;
import com.utopiaindustries.selftrucking.Activities.dashboardScreens.apiservice.ApiServiceFactory;
import com.utopiaindustries.selftrucking.models.DriverResponse;
import com.utopiaindustries.selftrucking.models.PickResponse;
import com.utopiaindustries.selftrucking.models.PickupRequest;

import retrofit2.Call;
import retrofit2.Callback;
import retrofit2.Response;

public class HomeViewModel extends ViewModel {

    private ApiService apiService;
    private MutableLiveData<String> errorLiveData;
    private MutableLiveData<Boolean> isLoading;
    private MutableLiveData<PickResponse> userLiveData;

    public HomeViewModel() {
        apiService = ApiServiceFactory.getApiService();
        errorLiveData = new MutableLiveData<>();
        isLoading = new MutableLiveData<>();
        userLiveData = new MutableLiveData<>();
    }

    public LiveData<PickResponse> getPickLiveData() {
        return userLiveData;
    }

    public LiveData<Boolean> getLoadingState() {
        return isLoading;
    }

    public LiveData<String> getErrorMessage() {
        return errorLiveData;
    }

    public void pickTruckLoad(PickupRequest pickupRequest) {

        isLoading.setValue(true);
        apiService.pickTruckLoad(pickupRequest).enqueue(new Callback<PickResponse>() {
            @Override
            public void onResponse(@NonNull Call<PickResponse> call, @NonNull Response<PickResponse> response) {
                isLoading.setValue(false);
                if (response.isSuccessful() && response.body() != null) {
                    userLiveData.setValue(response.body());

                } else {
                    errorLiveData.setValue(response.message());
                }
            }

            @Override
            public void onFailure(@NonNull Call<PickResponse> call, @NonNull Throwable t) {
                isLoading.setValue(false);
                errorLiveData.setValue(t.getMessage());
            }
        });
    }


}
