package com.utopiaindustries.selftrucking.Activities.loginScreens;

import android.content.Intent;
import android.os.Bundle;
import android.util.Log;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Toast;

import androidx.activity.EdgeToEdge;
import androidx.appcompat.app.AppCompatActivity;
import androidx.core.graphics.Insets;
import androidx.core.view.ViewCompat;
import androidx.core.view.WindowInsetsCompat;
import androidx.lifecycle.ViewModelProvider;

import com.utopiaindustries.selftrucking.Activities.dashboardScreens.HomeActivity;
import com.utopiaindustries.selftrucking.Activities.dashboardScreens.apiservice.ApiService;
import com.utopiaindustries.selftrucking.Activities.dashboardScreens.apiservice.ApiServiceFactory;
import com.utopiaindustries.selftrucking.Activities.loginScreens.viewModels.LoginViewModel;
import com.utopiaindustries.selftrucking.R;
import com.utopiaindustries.selftrucking.helper.Helper;
import com.utopiaindustries.selftrucking.helper.Preference;
import com.utopiaindustries.selftrucking.models.LoginRequest;
import com.utopiaindustries.selftrucking.utils.ProgressDialogFragment;

public class LoginActivity extends AppCompatActivity {

    EditText tfEmail, tfPassword;
    Button btnLogin;
    LoginViewModel loginViewModel;
    ApiService apiService;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        EdgeToEdge.enable(this);
        setContentView(R.layout.activity_login);
        ViewCompat.setOnApplyWindowInsetsListener(findViewById(R.id.main), (v, insets) -> {
            Insets systemBars = insets.getInsets(WindowInsetsCompat.Type.systemBars());
            v.setPadding(systemBars.left, systemBars.top, systemBars.right, systemBars.bottom);
            return insets;
        });

        if (!Helper.isNetworkConnected(this)) {
            Toast.makeText(this, "No Internet Connection", Toast.LENGTH_LONG).show();
        }

        initializeLayouts();

        btnLogin.setOnClickListener(v -> {
            if (isValidate()) {
                LoginRequest loginRequest = new LoginRequest(tfEmail.getText().toString(),
                        tfPassword.getText().toString());
                loginViewModel.authenticateUser(loginRequest);
            }
        });

    }

    private void initializeLayouts() {
        tfEmail = findViewById(R.id.tf_email);
        tfPassword = findViewById(R.id.tf_password);
        btnLogin = findViewById(R.id.btn_login);
        apiService = ApiServiceFactory.getApiService();

        /*tfEmail.setText("muhammad.mujtaba");
        tfPassword.setText("Utopia01");*/

        tfEmail.setText("anthony.pearlmen");
        //tfPassword.setText("%cw5R"5YmD");

        loginViewModel = new ViewModelProvider(this).get(LoginViewModel.class);

        loginViewModel.getLoadingState().observe(this, isLoading -> {
            if (isLoading != null && isLoading) {
                showProgressDialog();
            } else {
                dismissProgressDialog();
            }
        });

        loginViewModel.getErrorMessage().observe(this, errorResponse -> {
            if (errorResponse.isEmpty()) {
                Toast.makeText(this, "Something went wrong", Toast.LENGTH_SHORT).show();
            } else {
                Toast.makeText(this, errorResponse, Toast.LENGTH_SHORT).show();
            }

        });

        loginViewModel.getUserLiveData().observe(this, user -> {
            if (user != null) {
                Preference.setMyBooleanPref(Helper.project_file, "isLoggedIn", getApplicationContext(), true);
                Helper.setPreferenceObject(getApplicationContext(), user, "DriverResponse");

                Toast.makeText(this, "Welcome " + user.getTruckerName(), Toast.LENGTH_SHORT).show();
                Intent intent = new Intent(this, HomeActivity.class);
                startActivity(intent);
                overridePendingTransition(R.anim.slide_in_right, R.anim.slide_out_left);
                finish();
            } else {
                Toast.makeText(this, "Login Failed", Toast.LENGTH_SHORT).show();
            }
        });
    }

    public boolean isValidate() {
        boolean returnValue = true;
        String message = "";

        if (tfPassword.getText().toString().isEmpty()) {
            message = "Please enter password.";
            returnValue = false;
        }

        /*if (!Helper.isValidEmail(tfEmail.getText().toString())) {
            message = "Please enter valid email.";
            returnValue = false;
        }*/

        if (tfEmail.getText().toString().isEmpty()) {
            message = "Please enter user name.";
            returnValue = false;
        }

        if (!returnValue) {
            Toast.makeText(this, message, Toast.LENGTH_SHORT).show();
        }

        return returnValue;
    }

    public void showProgressDialog() {
        ProgressDialogFragment progressDialog = new ProgressDialogFragment();
        progressDialog.setCancelable(false);
        progressDialog.show(getSupportFragmentManager(), "progressDialog");
    }

    public void dismissProgressDialog() {
        ProgressDialogFragment progressDialog = (ProgressDialogFragment) getSupportFragmentManager().findFragmentByTag("progressDialog");
        if (progressDialog != null) {
            progressDialog.dismiss();
        }
    }
}