package com.utopiaindustries.selftrucking.Activities.loginScreens.viewModels;

import android.util.Log;

import androidx.lifecycle.LiveData;
import androidx.lifecycle.MutableLiveData;
import androidx.lifecycle.ViewModel;

import com.utopiaindustries.selftrucking.Activities.dashboardScreens.apiservice.ApiService;
import com.utopiaindustries.selftrucking.Activities.dashboardScreens.apiservice.ApiServiceFactory;
import com.utopiaindustries.selftrucking.models.DriverResponse;
import com.utopiaindustries.selftrucking.models.LoginRequest;

import retrofit2.Call;
import retrofit2.Callback;
import retrofit2.Response;

public class LoginViewModel extends ViewModel {

    private MutableLiveData<DriverResponse> userLiveData;
    private MutableLiveData<String> errorLiveData;
    private MutableLiveData<Boolean> isLoading;
    private ApiService apiService;

    public LoginViewModel() {
        apiService = ApiServiceFactory.getApiService();
        userLiveData = new MutableLiveData<>();
        errorLiveData = new MutableLiveData<>();
        isLoading = new MutableLiveData<>();
    }

    public LiveData<DriverResponse> getUserLiveData() {
        return userLiveData;
    }

    public LiveData<Boolean> getLoadingState() {

        return isLoading;
    }

    public LiveData<String> getErrorMessage() {
        return errorLiveData;
    }

    public void authenticateUser(LoginRequest loginRequest) {
        //Log.e("LoginRequest: ",""+loginRequest);
        isLoading.setValue(true);
        apiService.isUserAuthenticated(loginRequest).enqueue(new Callback<DriverResponse>() {
            @Override
            public void onResponse(Call<DriverResponse> call, Response<DriverResponse> response) {
                isLoading.setValue(false);
                //Log.e("Response: ",""+response);
                if (response.isSuccessful()  && response.body() != null) {
                    userLiveData.setValue(response.body());
                    //Log.e("Success-1",""+response.body());
                } else {
                    errorLiveData.setValue(response.message());
                    //Log.e("Else-2","****"+response.message());
                }
            }

            @Override
            public void onFailure(Call<DriverResponse> call, Throwable t) {
                isLoading.setValue(false);
                errorLiveData.setValue(t.getMessage());
                //Log.e("onFailure","****"+t.getMessage());
            }
        });
    }

    public LiveData<DriverResponse> getUser() {
        return userLiveData;
    }

    public LiveData<String> getError() {
        return errorLiveData;
    }
}
